@@ -17,7 +17,7 @@ import requests
 
 from ._service import _service_url
 from ._utils import (
-    get_logger,
+    _get_logger,
     _validate_base_directory,
     _lint_directory,
     _get_insight_name,
@@ -33,7 +33,7 @@ try:
 except:
     compression = zipfile.ZIP_STORED
 
-logger = get_logger()
+logger = _get_logger()
 
 
 def _init():
