@@ -10,7 +10,7 @@ import gzip
 from pathlib import Path
 
 
-def get_logger(level="INFO"):
+def _get_logger(level="INFO"):
     level = {
         "ERROR": logging.ERROR,
         "WARN": logging.WARN,
@@ -44,7 +44,7 @@ def _lint_directory(logger):
 
     for path in cwd.glob("**"):
         relative_path = path.relative_to(cwd)
-        if not is_hidden(relative_path):
+        if not _is_hidden(relative_path):
             type_hint_cmd = f'mypy --ignore-missing-imports {relative_path}'
             for return_path in _execute_iterator(type_hint_cmd):
                 if "error" in return_path and not "source file" in return_path:
@@ -86,8 +86,7 @@ def _execute_iterator(cmd, err_out=False):
 
 def _get_insight_name():
     # Regex extract alphabeticals and stick them back together snake case
-    dr = str(Path.cwd().parent)
-    words = re.findall("[a-zA-Z]+", dr)
+    words = re.findall("[a-zA-Z]+", Path.cwd().name)
     return "_".join(word.lower() for word in words)
 
 
@@ -135,7 +134,7 @@ def _gzip_dir(cwd):
     cwd = Path.cwd()
     for path in cwd.glob("**"):
         relative_path = path.relative_to(cwd)
-        if not is_hidden(path):
+        if not _is_hidden(path):
             with open(relative_path, "r") as f:
                 data[relative_path.as_posix()] = f.read()
     print(json.dumps(data, indent=4))
@@ -143,7 +142,7 @@ def _gzip_dir(cwd):
     # with gzip.GzipFile(fileobj=compressed)
 
 
-def is_hidden(path):
+def _is_hidden(path):
     """Checks whether a file is hidden or in a hidden directory"""
     for part in path.as_posix().split("/"):
         if part.startswith("."):
